# THz-STS-Algorithm
A compilation of functions to perform the steady-state terahertz scanning tunneling spectroscopy (THz-STS) algorithm described in Ammerman, S.E. et al. Nat Commun 12, 6794 (2021). https://doi.org/10.1038/s41467-021-26656-3 and functions to determine a true waveform from THz cross-correlation measurements described in ...

## Installation

Run the following to install

```python
pip install thzsts
```

## Usage

```python
from thzsts import algorithm

...

```